pub struct VarInt(pub u64);Expand description
A Bitcoin protocol variable-length integer.
VarInt is used in transaction data to indicate the number of upcoming fields or the length of an upcoming field. The encoding uses 1, 3, 5, or 9 bytes depending on the magnitude of the value.
Tuple Fields
0: u64Implementations
Sourceimpl VarInt
impl VarInt
Sourcepub fn from_bytes(data: &[u8]) -> Result<(Self, usize), PrimitivesError>
pub fn from_bytes(data: &[u8]) -> Result<(Self, usize), PrimitivesError>
Sourcepub fn upper_limit_inc(&self) -> i32
pub fn upper_limit_inc(&self) -> i32
Check if this value is at the upper boundary of a VarInt size class.
Returns how many extra bytes would be needed if the value were
incremented by 1. Returns -1 at u64::MAX (cannot increment).
Returns
0 if not at a boundary, 2 or 4 for size-class transitions, -1 at max.